Authors
=======

PyDAX is written and maintained by the CODAIT team at International Business Machines Corp. (IBM)

Primary co-maintainers:

* Hong Xu <hongx@ibm.com>
* Edward Leardi <edward@ibm.com>
* Daniel Jalova <djalova@us.ibm.com>
